import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 17
project_path = file_path[0:end]
sys.path.append(project_path)
# from mns_common.db.MongodbUtil import MongodbUtil
# import mns_common.component.k_line.common.k_line_common_service_api as k_line_common_service_api
#
# mongodb_util = MongodbUtil('27017')
# # query = {"deal_days": {"$exists": False}}
# deal_days = 8
# fail_id_list = []
# while True:
#     query = {"deal_days": deal_days}
#     realtime_quotes_now_zt_new_kc_open_df = mongodb_util.find_query_data('realtime_quotes_now_zt_new_kc_open', query)
#
#     for stock_one in realtime_quotes_now_zt_new_kc_open_df.itertuples():
#         try:
#             str_day = stock_one.str_day
#             deal_days = k_line_common_service_api.get_deal_days(str_day, stock_one.symbol)
#
#             realtime_quotes_now_zt_new_kc_open_one = realtime_quotes_now_zt_new_kc_open_df.loc[
#                 (realtime_quotes_now_zt_new_kc_open_df['symbol'] == stock_one.symbol)
#                 & (realtime_quotes_now_zt_new_kc_open_df['str_day'] == stock_one.str_day)]
#
#             realtime_quotes_now_zt_new_kc_open_one['deal_days'] = deal_days
#
#             mongodb_util.save_mongo(realtime_quotes_now_zt_new_kc_open_one, 'realtime_quotes_now_zt_new_kc_open')
#         except Exception as e:
#             mongodb_util.insert_mongo(realtime_quotes_now_zt_new_kc_open_one, 'realtime_quotes_now_zt_new_kc_open_fail')
#             print(stock_one.symbol)
#     deal_days = deal_days + 1
#     if deal_days > 3479:
#         print(deal_days)
#         break



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 17
project_path = file_path[0:end]
sys.path.append(project_path)

import akshare as ak
from loguru import logger
from datetime import datetime
import mns_common.utils.date_handle_util as date_handle_util
import mns_common.db.MongodbUtil as MongodbUtil
import mns_scheduler.backup.em.em_new_concept_sync_common_api as em_new_concept_sync_common_api
import mns_common.api.em.em_concept_index_api as em_concept_index_api

mongodb_util = MongodbUtil('27017')


# 同步概念k线
def sync_concept_k_line(symbol, period, start_date, end_date, adjust):
    try:
        stock_board_concept_hist_em_df = ak.stock_board_concept_hist_em(
            symbol=symbol, period=period, start_date=start_date, end_date=end_date, adjust=adjust
        )
        stock_board_concept_hist_em_df = stock_board_concept_hist_em_df.rename(columns={"日期": "date",
                                                                                        "开盘": "open",
                                                                                        "收盘": "close",
                                                                                        "最高": "high",
                                                                                        "最低": "low",
                                                                                        "涨跌幅": "chg",
                                                                                        "涨跌额": "change",
                                                                                        "成交量": "volume",
                                                                                        "成交额": "amount",
                                                                                        "振幅": "pct_chg",
                                                                                        "换手率": "exchange"
                                                                                        })

        return stock_board_concept_hist_em_df
    except BaseException as e:
        logger.error("同步东方财富概念信息异常:{}", e)
        return None


# 同步所有历史概念数据
def sync_his_em_concept():
    now_date = datetime.now()
    str_day = now_date.strftime('%Y-%m-%d')

    all_concept_list = em_concept_index_api.sync_all_concept()
    for stock_one in all_concept_list.itertuples():
        try:
            stock_one_df_copy = all_concept_list.loc[all_concept_list['concept_code'] == stock_one.concept_code]
            stock_one_df = stock_one_df_copy.copy()

            stock_board_concept_hist_em_df = sync_concept_k_line(
                symbol=stock_one.concept_name, period="daily", start_date="19980729",
                end_date=date_handle_util.no_slash_date(str_day), adjust="qfq"
            )
            stock_board_concept_hist_em_df = stock_board_concept_hist_em_df.sort_values(by=['date'], ascending=True)
            stock_board_concept_hist_em_df_first_day = stock_board_concept_hist_em_df.iloc[0:1]

            list_date = list(stock_board_concept_hist_em_df_first_day['date'])[0]
            str_now_time = list_date + " " + "09:10:00"
            stock_one_df.loc[:, 'str_now_time'] = str_now_time

            stock_one_df.loc[:, 'str_day'] = list_date

            stock_one_df['_id'] = stock_one_df['concept_code']
            stock_one_df['url'] = "http://quote.eastmoney.com/center/boardlist.html#boards-" + stock_one.concept_code
            stock_one_df['success'] = True

            mongodb_util.save_mongo(stock_one_df, 'em_concept_list')
            #
            concept_detail_list = em_new_concept_sync_common_api.sync_concept_detail(stock_one.concept_code)

            concept_detail_list.loc[:, 'concept_code'] = stock_one.concept_code
            concept_detail_list.loc[:, 'concept_name'] = stock_one.concept_name
            concept_detail_list.loc[:, 'str_day'] = list_date

            concept_detail_list.loc[:, 'str_now_time'] = str_now_time

            concept_detail_list['_id'] = concept_detail_list['symbol'] + '-' + concept_detail_list['concept_code']

            mongodb_util.insert_mongo(concept_detail_list, 'em_stock_concept_detail')
        except BaseException as e:
            logger.error("发生异常:{}", e)
            continue


if __name__ == '__main__':
    # all_concept = sync_all_concept()
    # all_concept = all_concept.loc[~(all_concept['list_day'] == '-')]
    # all_concept = all_concept.sort_values(by=['list_day'], ascending=False)
    sync_his_em_concept()
    # stock_board_concept_hist_em_df = sync_concept_k_line(
    #     symbol="车联网", period="daily", start_date="20220101", end_date="20221128", adjust=""
    # )
    # sync_concept_detail('MLOps概念')



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)
import mns_common.api.em.east_money_stock_hk_api as east_money_stock_hk_api
import akshare as ak
import mns_common.constant.db_name_constant as db_name_constant
from mns_common.db.MongodbUtil import MongodbUtil

mongodb_util = MongodbUtil('27017')
COOKIE = 'qgqp_b_id=1e0d79428176ed54bef8434efdc0e8c3; mtp=1; ct=QVRY_s8Tiag1WfK2tSW2n03qpsX-PD8aH_rIjKVooawX8K33UVnpIofK088lD1lguWlE_OEIpQwn3PJWFPhHvSvyvYr4Zka3l4vxtZfH1Uikjtyy9z1H4Swo0rQzMKXncVzBXiOo5TjE-Dy9fcoG3ZF7UVdQ35jp_cFwzOlpK5Y; ut=FobyicMgeV51lVMr4ZJXvn-72bp0oeSOvtzifFY_U7kBFtR6og4Usd-VtBM5XBBvHq0lvd9xXkvpIqWro9EDKmv6cbKOQGyawUSMcKVP57isZCaM7lWQ6jWXajvTfvV4mIR-W_MZNK8VY0lL9W4qNMniJ6PBn_gkJsSAJCadmsyI9cxmjx--gR4m54pdF_nie_y4iWHys83cmWR2R7Bt1KKqB25OmkfCQTJJqIf7QsqangVGMUHwMC39Z9QhrfCFHKVNrlqS503O6b9GitQnXtvUdJhCmomu; pi=4253366368931142%3Bp4253366368931142%3B%E8%82%A1%E5%8F%8B9x56I87727%3BYNigLZRW%2FzMdGgVDOJbwReDWnTPHl51dB0gQLiwaCf1XY98mlJYx6eJbsoYr5Nie%2BX1L%2BzaMsec99KkX%2BT29Ds1arfST7sIBXxjUQ3dp11IPUnXy64PaBFRTHzMRWnCFJvvhc%2FAI41rXSGXolC8YMxI%2BvyPS%2BuErwgOVjC5vvsIiKeO7TLyKkhqqQJPX%2F7RWC5Sf3QLh%3Bdwjn4Xho10%2FKjqOgTWs%2FJF4%2FkdKzeuBwM8sz9aLvJovejAkCAyGMyGYA6AE67Xk2Ki7x8zdfBifF2DG%2Fvf2%2BXAYN8ZVISSEWTIXh32Z5MxEacK4JBTkqyiD93e1vFBOFQ82BqaiVmntUq0V6FrTUHGeh1gG5Sg%3D%3D; uidal=4253366368931142%e8%82%a1%e5%8f%8b9x56I87727; sid=170711377; vtpst=|; quote_lt=1; websitepoptg_api_time=1715777390466; emshistory=%5B%22%E8%BD%AC%E5%80%BA%E6%A0%87%22%2C%22%E8%BD%AC%E5%80%BA%E6%A0%87%E7%9A%84%22%5D; st_si=00364513876913; st_asi=delete; HAList=ty-116-00700-%u817E%u8BAF%u63A7%u80A1%2Cty-1-688695-%u4E2D%u521B%u80A1%u4EFD%2Cty-1-600849-%u4E0A%u836F%u8F6C%u6362%2Cty-1-603361-%u6D59%u6C5F%u56FD%u7965%2Cty-1-603555-ST%u8D35%u4EBA%2Cty-0-000627-%u5929%u8302%u96C6%u56E2%2Cty-0-002470-%u91D1%u6B63%u5927%2Cty-0-832876-%u6167%u4E3A%u667A%u80FD%2Cty-0-300059-%u4E1C%u65B9%u8D22%u5BCC%2Cty-107-CWB-%u53EF%u8F6C%u503AETF-SPDR; st_pvi=26930719093675; st_sp=2024-04-28%2017%3A27%3A05; st_inirUrl=https%3A%2F%2Fcn.bing.com%2F; st_sn=23; st_psi=20240517111108288-113200301321-2767127768'


def get_hk_ggt_component():
    stock_hk_ggt_components_em_df = ak.stock_hk_ggt_components_em()
    stock_hk_ggt_components_em_df = stock_hk_ggt_components_em_df.rename(columns={
        "序号": "index",
        "代码": "symbol",
        "名称": "name"
    })
    return stock_hk_ggt_components_em_df


# https://quote.eastmoney.com/center/gridlist.html#hk_stocks
def sync_hk_company_info():
    hk_real_time_df = east_money_stock_hk_api.hk_real_time_quotes(COOKIE)

    hk_real_time_df = hk_real_time_df[[
        "symbol",
        "name",
        "chg",
        "total_mv",
        "flow_mv",
        "list_date",
        "industry",
        "amount",
        "now_price"
    ]]
    # 排除基金
    hk_real_time_df = hk_real_time_df.loc[hk_real_time_df['total_mv'] != '-']

    stock_hk_ggt_components_em_df = get_hk_ggt_component()
    stock_hk_ggt_components_symbol_list = list(stock_hk_ggt_components_em_df['symbol'])
    hk_real_time_df['hk_ggt'] = False
    hk_real_time_df.loc[hk_real_time_df['symbol'].isin(stock_hk_ggt_components_symbol_list), 'hk_ggt'] = True
    hk_real_time_df.loc[hk_real_time_df['industry'] == '-', 'industry'] = '其他'

    hk_real_time_df['_id'] = hk_real_time_df['symbol']

    hk_real_time_df.fillna(0, inplace=True)

    mongodb_util.save_mongo(hk_real_time_df, db_name_constant.COMPANY_INFO_HK)


if __name__ == '__main__':
    sync_hk_company_info()
